<?php
	/**
	 * Provide a admin area view for the plugin
	 *
	 * This file is used to markup the admin-facing aspects of the plugin.
	 *
	 * @link       https://www.swascan.com
	 * @since      0.9
	 *
	 * @package    GDPR-WP
	 * @subpackage GDPR-WP/admin/partials
	 */

	// check user capabilities
	if ( ! current_user_can( 'manage_options' ) ) {
		return;
	}
	$requests = get_option( 'gdpr_wp_requests' ) ? get_option( 'gdpr_wp_requests' ) : array();
?>
<style>
.wrap h1 {
	padding: 40px 0;
}

.wrap .logo {
	max-width: 60px;
	float: right;
}

.wrap .logo img {
	width: 100%;
	height: auto;
}

.wrap .logo:after {
	clear: both;
}

.clear {
	clear: both;
}

.postbox-container .postbox {
	background-color: #0079C5;
}

.postbox-container .postbox h2 {
	color: #fff;
}

.postbox-container .postbox .inside {
	border-top: 1px solid #fff;
	padding-top: 10px;
	color: #fff;
}

.postbox-container .postbox .inside a {
	color: #FEA92C;
}

</style>
<div class="wrap">
	<h1><?php echo esc_html( get_admin_page_title() ); ?><span class="logo"><a href="https://www.swascan.com" targer="_blank"><img src="<?php echo plugin_dir_url( __FILE__ ); ?>/img/logo.png" alt="" /></a></span></h1>
	<div id="poststuff">
		<div id="post-body" class="metabox-holder columns-2">
			<div id="post-body-content">
				<?php	settings_errors( 'gdpr_wp_messages' ); ?>
				<div class="postbox">
					<h2><?php echo _e( 'Add to Requests Table', 'gdpr-wp' ); ?></h2>
					<div class="inside">
						<form class="gdpr-manual-email-lookup" method="post" action="">
							<input type="hidden" name="gdpr_wp_action" value="requests_email_lookup">
							<?php wp_nonce_field( 'gdpr-request-email-lookup', '_gdpr_wp_email_lookup' ); ?>
							<input type="email" name="email" class="regular-text" id="gdpr-email-lookup-field" placeholder="<?php esc_attr_e( 'email@domain.com', 'gdpr-wp' ); ?>" required>
							<span class="spinner"></span>
							<?php submit_button( 'Submit', 'primary', '', false ); ?>
						</form>
					</div>
				</div>
				<?php if ( ! empty( $requests ) ) : ?>
					<div class="postbox">
						<table class="widefat" id="gdpr-requests-table">
							<thead>
								<tr>
									<th class="text-center"><?php esc_attr_e( 'ID', 'gdpr-wp' ); ?></th>
									<th><?php esc_attr_e( 'Full Name', 'gdpr-wp' ); ?></th>
									<th><?php esc_attr_e( 'Email', 'gdpr-wp' ); ?></th>
									<th class="text-center"><?php esc_attr_e( 'Date of Request', 'gdpr-wp' ); ?></th>
									<th class="text-center"><?php esc_attr_e( 'Time Left', 'gdpr-wp' ); ?></th>
									<th class="text-center"><?php esc_attr_e( 'Review', 'gdpr-wp' ); ?></th>
								</tr>
							</thead>
							<tbody>
								<?php foreach ($requests as $ID => $user ): ?>
									<?php
										$diff = self::get_days_left( $user['requested_on'], 30 );
										$class = '';
										if ( $diff <= 7 ) {
											$class = 'gdpr-urgent';
										} else if ( $diff <= 15 ) {
											$class = 'gdpr-warning';
										}
									?>
									<tr class="<?php echo esc_attr( $class ) ?>" data-uid="<?php echo esc_attr( $ID ) ?>">
										<td class="text-center"><?php echo esc_html( $ID ) ?></td>
										<td><?php echo esc_html( $user['full_name'] ); ?></td>
										<td><?php echo esc_html( $user['email'] ); ?></td>
										<td class="text-center"><?php echo esc_html( $user['requested_on'] ); ?></td>
										<td class="text-center"><?php echo sprintf( esc_html__( '%s days', 'gdpr-wp' ), $diff ) ?></td>
										<td class="text-center">
											<div data-uid="<?php echo esc_attr( $ID ); ?>">
												<?php wp_nonce_field( 'gdpr-process-request-delete-action', '_delete-without-review-nonce' ) ?>
												<button class="button gdpr-request-cancel"><?php _e( 'Cancel', 'gdpr-wp' ); ?></button>
												<button class="button gdpr-review"><?php _e( 'Review', 'gdpr-wp' ); ?></button>
												<button class="button-primary gdpr-request-delete"><?php _e( 'Delete', 'gdpr-wp' ); ?></button>
												<span class="spinner"></span>
											</div>
										</td>
									</tr>
									<tr data-uid="<?php echo esc_attr( $ID ) ?>">
										<td colspan="7">
											<div class="gdpr-review-table-<?php echo esc_attr( $ID ); ?>">
												<table class="widefat">
													<thead>
														<tr>
															<th><?php esc_html_e( 'Content Type', 'gdpr-wp' ); ?></th>
															<th class="text-center"><?php _e( 'Count', 'gdpr-wp' ); ?></th>
															<th class="text-center"><?php _e( 'Review', 'gdpr-wp' ); ?></th>
															<th class="text-center"><?php _e( 'Reassign to', 'gdpr-wp' ); ?></th>
															<th class="text-center"><?php _e( 'Actions', 'gdpr-wp' ); ?></th>
														</tr>
													</thead>
													<tbody>
														<?php $post_types = get_post_types( array( 'public' => true ) ); ?>
														<?php foreach ( $post_types as $pt ): ?>
															<?php
																$count = count_user_posts( $ID, $pt );
																if ( '0' === $count) {
																	continue;
																}
															?>
															<tr data-pt="<?php echo esc_attr( $pt ) ?>" data-uid="<?php echo esc_attr( $ID ) ?>">
																<td class="row-title"><?php echo esc_html( $pt ); ?></td>
																<td class="text-center"><?php echo esc_html( $count ); ?></td>
																<td class="text-center"><a href="<?php echo admin_url('edit.php?post_type=' . $pt . '&author=' . $ID); ?>" target="_blank" class="button"><?php _e( 'Review', 'gdpr-wp' ); ?></a></td>
																<td class="text-center">
																	<select name="reassign_to" class="gdpr-reassign" data-pt="<?php echo esc_attr( $pt ) ?>" data-uid="<?php echo esc_attr( $ID ); ?>">
																		<option value=""></option>
																		<?php $admins = get_users( array( 'role' => 'administrator' ) ); ?>
																		<?php foreach ( $admins as $admin ): ?>
																			<option value="<?php echo esc_attr( $admin->ID ) ?>"><?php echo esc_html( $admin->display_name ) ?></option>
																		<?php endforeach; ?>
																	</select>
																</td>
																<td class="text-center">
																	<form method="post" class="gdpr-form-process-request" data-uid="<?php echo esc_attr( $ID ) ?>" data-pt="<?php echo esc_attr( $pt ); ?>" data-reassign="" data-count="<?php echo esc_attr( $count ) ?>">
																		<?php wp_nonce_field( 'gdpr-process-request-reassign-action', '_reassign-nonce' ) ?>
																		<button class="button-primary gdpr-reassign-button" data-pt="<?php echo esc_attr( $pt ) ?>" data-uid="<?php echo esc_attr( $ID ); ?>"><?php _e( 'Reassign', 'gdpr-wp' ); ?></button>
																		<span class="spinner"></span>
																		<p style="display:none;"><strong><?php _e('Resolved', 'gdpr-wp'); ?></strong></p>
																	</form>
																</td>
															</tr>
														<?php endforeach; ?>
														<?php
															$comment_count = get_comments( array(
																'author_email' => $user['email'],
																'include_unapproved' => true,
																'count' => true,
															) );

															if ( $comment_count ) {
																?>
																	<tr data-pt="comments" data-uid="<?php echo esc_attr( $ID ) ?>">
																		<td class="row-title"><?php esc_html_e( 'Comments', 'gdpr-wp' ); ?></td>
																		<td class="text-center"><?php echo esc_html( $comment_count ); ?></td>
																		<td class="text-center"><a href="<?php echo admin_url( 'edit-comments.php?comment_status=all&s=' . urlencode( $user['email'] ) ); ?>" target="_blank" class="button"><?php _e( 'Review', 'gdpr-wp' ); ?></a></td>
																		<td class="text-center"></td>
																		<td class="text-center">
																			<form method="post" class="gdpr-form-process-request" data-uid="<?php echo esc_attr( $ID ) ?>" data-pt="<?php echo esc_attr( $pt ); ?>" data-count="<?php echo esc_attr( $comment_count ) ?>">
																				<?php wp_nonce_field( 'gdpr-anonymize-comments-action', '_anonymize-nonce' ) ?>
																				<button class="button-primary gdpr-anonymize-button" data-uid="<?php echo esc_attr( $ID ); ?>"><?php _e( 'Anonymize', 'gdpr-wp' ); ?></button>
																				<span class="spinner"></span>
																				<p style="display:none;"><strong><?php _e('Resolved', 'gdpr-wp'); ?></strong></p>
																			</form>
																		</td>
																	</tr>
																<?php
															}
														?>
													</tbody>
												</table>
											</div>
										</td>
									</tr>
								<?php endforeach; ?>
							</tbody>
						</table>
					</div>
				<?php endif; ?>
			</div>
			<div id="postbox-container-1" class="postbox-container">
				<div class="postbox">
					<h2>About the plugin</h2>
					<div class="inside">
						This plugin help website owners to comply with European privacy regulations (GDPR). Within May 24th, 2018 all the websites must comply with this regulation. The plugin is brought to you by <a href="https://www.swascan.com" target="_blank">Swascan</a> which provides all the tools and resources you may need to comply with the <a href="https://www.swascan.com/swascan-gdpr-compliance" target="_blank">GDPR</a> and to <a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">scan your web for vulnerabilities</a>.
					</div>
				</div>
				<div class="postbox">
					<h2>Swascan Services</h2>
					<div class="inside">
						<ul>
							<li><a href="https://www.swascan.com/#gdpr-assessment" target="_blank">GDPR Assessment</a></li>
							<li><a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">Vulnerability Assessment</a></li>
							<li><a href="https://www.swascan.com/#network-scan" target="_blank">Network Scan</a></li>
						</ul>
					</div>
				</div>
				<div class="postbox">
					<h2>Warning</h2>
					<div class="inside">
						ACTIVATING THIS PLUGIN DOES NOT GUARANTEE THAT AN ORGANIZATION IS SUCCESSFULLY MEETING ITS RESPONSIBILITIES AND OBLIGATIONS OF <a href="https://www.swascan.com/swascan-gdpr-compliance" target="_blank">GDPR</a>. INDIVIDUAL ORGANIZATIONS SHOULD ASSESS THEIR UNIQUE RESPONSIBILITIES AND ENSURE EXTRA MEASURES ARE TAKE TO MEET ANY OBLIGATIONS REQUIRED BY LAW AND BASED ON A <a href="https://www.swascan.com/#vulnerability-assessment" target="_blank">DATA PROTECTION IMPACT ASSESSMENT</a> (DPIA).
					</div>
				</div>
			</div>
		</div>
	</div>
</div>
<?php
