<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://www.swascan.com
 * @since             0.9
 * @package           GDPR
 *
 * @wordpress-plugin
 * Plugin Name:       GDPR for WP
 * Description:       This plugin helps website owners to comply with European privacy regulations (GDPR).
 * Version:           0.9
 * Author:            Swascan
 * Author URI:        https://www.swascan.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       gdpr-wp
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently pligin version.
 * Start at version 0.9 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GDPR_WP_VERSION', '0.9' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-gdpr-wp-activator.php
 */
function activate_GDPR_WP() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-wp-activator.php';
	GDPR_WP_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-gdpr-wp-deactivator.php
 */
function deactivate_GDPR_WP() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-wp-deactivator.php';
	GDPR_WP_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_GDPR_WP' );
register_deactivation_hook( __FILE__, 'deactivate_GDPR_WP' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-gdpr-wp.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    0.9
 */
function run_GDPR_WP() {

	$plugin = new GDPR_WP();
	$plugin->run();

}
add_action( 'plugins_loaded', 'run_GDPR_WP' );
